@@ -18,6 +18,7 @@
 # Refer to the README and COPYING files for full details of the license
 #
 
+from __future__ import absolute_import
 from .. import UsageError
 
 
@@ -27,40 +28,17 @@ class InvalidConfig(UsageError):
 
 
 class InvalidRun(UsageError):
-    """ raise when the environemnt is not valid to run the command """
+    """ raise when the environment is not valid to run the command """
     pass
 
 # Declare state of configuration
 #
-# CONFIGURED     = Module is set properly without any required changes on
-#                  force.
-# NOT_CONFIGURED = Module is not set properly for VDSM and need to be
-#                  configured.
-# NOT_SURE       = VDSM configured module already but on force configure vdsm
-#                  will set configurations to defaults parameters.
+# YES   = Module configured.
 #
-CONFIGURED, NOT_CONFIGURED, NOT_SURE = range(3)
-
-
-class ModuleConfigure(object):
-
-    def getName(self):
-        return None
-
-    def getServices(self):
-        return []
-
-    def validate(self):
-        return True
-
-    def configure(self):
-        pass
-
-    def isconfigured(self):
-        return NOT_CONFIGURED
-
-    def removeConf(self):
-        pass
-
-    def getRequires(self):
-        return set()
+# NO    = Module not configured before.
+#
+# MAYBE = Module configured before,
+#         configuration validity could not be determined.
+#
+# See also --force at configurators.py.
+YES, NO, MAYBE = tuple(range(3))
