@@ -27,7 +27,7 @@ plentifuly around vdsm.
 
     Contains a reverse dictionary pointing from error string to its error code.
 """
-from collections import namedtuple, deque
+from collections import namedtuple, deque, OrderedDict
 from contextlib import contextmanager
 from fnmatch import fnmatch
 from StringIO import StringIO
@@ -1277,3 +1277,11 @@ def stopwatch(message, log=logging.getLogger('vds.stopwatch')):
         log.debug("%s: %.2f seconds", message, elapsed)
     else:
         yield
+
+
+def unique(iterable):
+    """
+    Return unique items from iterable of hashable objects, keeping the
+    original order.
+    """
+    return OrderedDict.fromkeys(iterable).keys()
