@@ -22,7 +22,7 @@
 
 from vdsm import netinfo
 
-from testrunner import VdsmTestCase as TestCaseBase
+from testlib import VdsmTestCase as TestCaseBase
 from monkeypatch import MonkeyPatch
 
 from network import api, configurators
@@ -44,7 +44,7 @@ class TestConfigNetwork(TestCaseBase):
 
     def _addNetworkWithExc(self, netName, opts, errCode):
         with self.assertRaises(errors.ConfigNetworkError) as cneContext:
-            api.addNetwork(netName, **opts)
+            api._addNetwork(netName, **opts)
         self.assertEqual(cneContext.exception.errCode, errCode)
 
     # Monkey patch the real network detection from the netinfo module.
@@ -53,7 +53,7 @@ class TestConfigNetwork(TestCaseBase):
     @MonkeyPatch(netinfo, 'getMtu', lambda *x: 1500)
     @MonkeyPatch(configurators.ifcfg, 'ifdown', lambda *x:
                  _raiseInvalidOpException())
-    @MonkeyPatch(configurators.ifcfg, 'ifup',
+    @MonkeyPatch(configurators.ifcfg, '_exec_ifup',
                  lambda *x: _raiseInvalidOpException())
     @MonkeyPatch(Bond, 'configure', lambda *x: _raiseInvalidOpException())
     @MonkeyPatch(Bridge, 'configure', lambda *x: _raiseInvalidOpException())
@@ -144,23 +144,6 @@ class TestConfigNetwork(TestCaseBase):
         self._addNetworkWithExc('test', dict(nics=['eth6'], _netinfo=fakeInfo),
                                 errors.ERR_USED_NIC)
 
-        # Test for adding a new VLANed bridged network when a non-VLANed
-        # bridged network exists
-        self._addNetworkWithExc('test', dict(vlan='2', bonding='bond00',
-                                nics=nics, _netinfo=fakeInfo),
-                                errors.ERR_BAD_PARAMS)
-
-        # Test for adding a new VLANed bridgeless network when a non-VLANed
-        # bridged network exists
-        self._addNetworkWithExc('test', dict(vlan='2', bonding='bond00',
-                                nics=nics, bridged=False, _netinfo=fakeInfo),
-                                errors.ERR_BAD_PARAMS)
-
-        # Test for adding a new VLANed bridged network when the interface is in
-        # use by any type of networks
-        self._addNetworkWithExc('test', dict(nics=['eth7'], _netinfo=fakeInfo),
-                                errors.ERR_BAD_PARAMS)
-
         # Test for adding a new non-VLANed bridgeless network when a non-VLANed
         # bridgeless network exists
         self._addNetworkWithExc('test', dict(nics=['eth8'], bridged=False,
